<?php


/*
 * Custom control class
 *
 * Add description on control
 * */
if ( class_exists('WP_Customize_Control') ) {
class WPMUDEV_Customize_Control extends WP_Customize_Control {

	public $description = '';

	protected function render_content() {
		switch( $this->type ) {
			default:
				return parent::render_content();
			case 'text':
				?>
				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<?php if ( isset($this->description) && !empty($this->description) ): ?>
					<span class="customize-control-description"><?php echo $this->description ?></span>
					<?php endif ?>
					<input type="text" value="<?php echo esc_attr( $this->value() ); ?>" <?php $this->link(); ?> />
				</label>
				<?php
				break;
			case 'checkbox':
				?>
				<label>
					<input type="checkbox" value="<?php echo esc_attr( $this->value() ); ?>" <?php $this->link(); checked( $this->value() ); ?> />
					<?php echo esc_html( $this->label ); ?>
				</label>
				<?php if ( isset($this->description) && !empty($this->description) ): ?>
				<span class="customize-control-description"><?php echo $this->description ?></span>
				<?php endif ?>
				<?php
				break;
			case 'radio':
				if ( empty( $this->choices ) )
					return;

				$name = '_customize-radio-' . $this->id;

				?>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<?php if ( isset($this->description) && !empty($this->description) ): ?>
				<span class="customize-control-description"><?php echo $this->description ?></span>
				<?php endif ?>
				<?php
				foreach ( $this->choices as $value => $label ) :
					?>
					<label>
						<input type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>" <?php $this->link(); checked( $this->value(), $value ); ?> />
						<?php echo esc_html( $label ); ?><br/>
					</label>
					<?php
				endforeach;
				break;
			case 'custom-radio':
				if ( empty( $this->choices ) )
					return;

				$name = '_customize-radio-' . $this->id;

				?>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<?php if ( isset($this->description) && !empty($this->description) ): ?>
				<span class="customize-control-description"><?php echo $this->description ?></span>
				<?php endif ?>
				<?php
				foreach ( $this->choices as $value => $label ) :
					$screenshot_img = substr($value,0,-4);
					?>
					<label>
						<div class="theme-img">
							<img src="<?php echo get_template_directory_uri(); ?>/_inc/preset-styles/images/<?php echo $screenshot_img . '.png'; ?>" alt="<?php echo $screenshot_img ?>" />
						</div>
						<input type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>" <?php $this->link(); checked( $this->value(), $value ); ?> />
						<?php echo esc_html( $label ); ?><br/>
					</label>
					<?php
				endforeach;
				break;
			case 'select':
				if ( empty( $this->choices ) )
					return;

				?>
				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<?php if ( isset($this->description) && !empty($this->description) ): ?>
					<span class="customize-control-description"><?php echo $this->description ?></span>
					<?php endif ?>
					<select <?php $this->link(); ?>>
						<?php
						foreach ( $this->choices as $value => $label )
							echo '<option value="' . esc_attr( $value ) . '"' . selected( $this->value(), $value, false ) . '>' . $label . '</option>';
						?>
					</select>
				</label>
				<?php
				break;
			// Handle textarea
			case 'textarea':
				?>
				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<?php if ( isset($this->description) && !empty($this->description) ): ?>
					<span class="customize-control-description"><?php echo $this->description ?></span>
					<?php endif ?>
					<textarea rows="10" cols="40" <?php $this->link(); ?>><?php echo esc_attr( $this->value() ); ?></textarea>
				</label>
				<?php
				break;
		}
	}

}
}

if ( class_exists('WP_Customize_Color_Control') ) {
class WPMUDEV_Customize_Color_Control extends WP_Customize_Color_Control {

	public $description = '';

	public function render_content() {
		$this_default = $this->setting->default;
		$default_attr = '';
		if ( $this_default ) {
			if ( false === strpos( $this_default, '#' ) )
				$this_default = '#' . $this_default;
			$default_attr = ' data-default-color="' . esc_attr( $this_default ) . '"';
		}
		// The input's value gets set by JS. Don't fill it.
		?>
		<label>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<?php if ( isset($this->description) && !empty($this->description) ): ?>
			<span class="customize-control-description"><?php echo $this->description ?></span>
			<?php endif ?>
			<div class="customize-control-content">
				<input class="color-picker-hex" type="text" maxlength="7" placeholder="<?php esc_attr_e( 'Hex Value' ); ?>"<?php echo $default_attr ?> />
			</div>
		</label>
		<?php
	}
}
}

if ( class_exists('WP_Customize_Image_Control') ) {

class WPMUDEV_Customize_Image_Control extends WP_Customize_Image_Control {

	public $description = '';

	public function render_content() {
		$src = $this->value();
		if ( isset( $this->get_url ) )
			$src = call_user_func( $this->get_url, $src );

		?>
		<div class="customize-image-picker">
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<?php if ( isset($this->description) && !empty($this->description) ): ?>
			<span class="customize-control-description"><?php echo $this->description ?></span>
			<?php endif ?>

			<div class="customize-control-content">
				<div class="dropdown preview-thumbnail" tabindex="0">
					<div class="dropdown-content">
						<?php if ( empty( $src ) ): ?>
							<img style="display:none;" />
						<?php else: ?>
							<img src="<?php echo esc_url( set_url_scheme( $src ) ); ?>" />
						<?php endif; ?>
						<div class="dropdown-status"></div>
					</div>
					<div class="dropdown-arrow"></div>
				</div>
			</div>

			<div class="library">
				<ul>
					<?php foreach ( $this->tabs as $id => $tab ): ?>
						<li data-customize-tab='<?php echo esc_attr( $id ); ?>' tabindex='0'>
							<?php echo esc_html( $tab['label'] ); ?>
						</li>
					<?php endforeach; ?>
				</ul>
				<?php foreach ( $this->tabs as $id => $tab ): ?>
					<div class="library-content" data-customize-tab='<?php echo esc_attr( $id ); ?>'>
						<?php call_user_func( $tab['callback'] ); ?>
					</div>
				<?php endforeach; ?>
			</div>

			<div class="actions">
				<a href="#" class="remove"><?php _e( 'Remove Image' ); ?></a>
			</div>
		</div>
		<?php
	}
}
}


function bpdaily_customize_register( $wp_customize ) {
	global $options, $options2, $options3, $shortname, $shortprefix;
	$options_list = array_merge($options, $options2, $options3);
	$sections = array(
		array(
			'section' => 'style',
			'title' => __("Preset Style", 'bp-daily'),
			'priority' => 30
		),
		array(
			'section' => 'featured',
			'title' => __("Home page Featured Content Settings", 'bp-daily'),
			'priority' => 31
		),array(
			'section' => 'content',
			'title' => __("Home Page Content Settings", 'bp-daily'),
			'priority' => 32
		),array(
			'section' => 'spotlight',
			'title' => __("Spotlight Settings", 'bp-daily'),
			'priority' => 33
		),array(
			'section' => 'advert',
			'title' => __("Advert Settings", 'bp-daily'),
			'priority' => 34
		),array(
			'section' => 'header',
			'title' => __("Header area settings *not custom header", 'bp-daily'),
			'priority' => 35
		),array(
			'section' => 'headers',
			'title' => __("Headers styling", 'bp-daily'),
			'priority' => 36
		),array(
			'section' => 'forms',
			'title' => __("Forms and buttons styling", 'bp-daily'),
			'priority' => 37
		),array(
			'section' => 'text',
			'title' => __("Text and links styling", 'bp-daily'),
			'priority' => 38
		),array(
			'section' => 'layout',
			'title' => __("Layout styling", 'bp-daily'),
			'priority' => 39
		),array(
			'section' => 'navigation',
			'title' => __("Navigation styling", 'bp-daily'),
			'priority' => 40
		),array(
			'section' => 'messages',
			'title' => __("Messages styling", 'bp-daily'),
			'priority' => 41
		)/*,array(
			'section' => 'featured',
			'title' => __("Featured content styling", 'bp-daily'),
			'priority' => 42
		)*/

	);
	// Add sections
	foreach ( $sections as $section ) {
		$wp_customize->add_section( $shortname . $shortprefix . $section['section'], array(
			'title' => $section['title'],
			'priority' => $section['priority']
		) );
	}
	// Add settings and controls
	$opt_section = '';
	foreach ( $options_list as $o => $option ) {
		if ( ! bpdaily_option_in_customize($option) )
			continue;
		$transport = 'postMessage';
		$wp_customize->add_setting( $option['id'], array(
			'default' => ( isset($option['std']) ? $option['std'] : '' ),
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'transport' => $transport
		) );
		$control_param = array(
			'label' => strip_tags($option['name']),
			'description' => ( isset($option['description']) && !empty($option['description']) ? $option['description'] : '' ),
			'section' => $shortname . $shortprefix . $option['inblock'],
			'settings' => $option['id'],
			'priority' => $o // make sure we have the same order as theme options :)
		);
		if ( $option['type'] == 'color' || $option['type'] == 'colorpicker' ) {
			$wp_customize->add_control( new WPMUDEV_Customize_Color_Control( $wp_customize, $option['id'].'_control', $control_param ) );
		}
		else if ( $option['type'] == 'image' ) {
			$control_param['type'] = $option['type'];
			$wp_customize->add_control( new WPMUDEV_Customize_Image_Control( $wp_customize, $option['id'].'_control', $control_param) );
		}
		else if ( $option['type'] == 'text' || $option['type'] == 'textarea' || $option['type'] == 'checkbox' ) {
			$control_param['type'] = $option['type'];
			$wp_customize->add_control( new WPMUDEV_Customize_Control( $wp_customize, $option['id'].'_control', $control_param) );
		}
		else if ( $option['type'] == 'custom-radio' ) {
			$control_param['type'] ='custom-radio';
			// @TODO choices might get removed in future
			$choices = array();
			foreach ( $option['options'] as $choice )
				$choices[$choice] = $choice;
			$control_param['choices'] = $choices;
			$wp_customize->add_control( new WPMUDEV_Customize_Control( $wp_customize, $option['id'].'_control', $control_param) );
		}
		else if ( $option['type'] == 'select' || $option['type'] == 'select-preview' ) {
			$control_param['type'] = 'select';
			// @TODO choices might get removed in future
			$choices = array();
			foreach ( $option['options'] as $choice )
				$choices[$choice] = $choice;
			$control_param['choices'] = $choices;
			$wp_customize->add_control( new WPMUDEV_Customize_Control( $wp_customize, $option['id'].'_control', $control_param) );
		}
	}

	// Support Wordpress custom background
	$wp_customize->get_setting('background_color')->transport = 'postMessage';
	$wp_customize->get_setting('background_image')->transport = 'postMessage';
	$wp_customize->get_setting('background_repeat')->transport = 'postMessage';
	$wp_customize->get_setting('background_position_x')->transport = 'postMessage';
	$wp_customize->get_setting('background_attachment')->transport = 'postMessage';
	$wp_customize->get_setting('header_image')->transport = 'postMessage';
	$wp_customize->get_setting('header_textcolor')->transport = 'postMessage';
	$wp_customize->get_setting('blogname')->transport = 'postMessage';
	$wp_customize->get_setting('blogdescription')->transport = 'postMessage';
}
add_action('customize_register', 'bpdaily_customize_register');

function bpdaily_customize_preview() {
	global $options, $shortname, $shortprefix;
	?>
	<div id="theme-customizer-css"></div>

	<script type="text/javascript">
		var theme_prefix = "<?php echo $shortname . $shortprefix ?>";
		var theme_url = "<?php echo get_template_directory_uri() ?>";
	</script>
	<?php
}

function bpdaily_customize_init() {
	global $theme_version;
	add_action('wp_footer', 'bpdaily_customize_preview', 21);
	wp_enqueue_script( 'bpdaily-theme-customizer', get_template_directory_uri() . '/library/scripts/theme-customizer.js', array( 'customize-preview' ), $theme_version );
	wp_enqueue_script( 'bpdaily-theme-customizer-options', get_template_directory_uri() . '/library/scripts/theme-customizer-options.js', array( 'customize-preview' ), $theme_version );
}
add_action( 'customize_preview_init', 'bpdaily_customize_init' );

// Add additional styling to better fit on Customizer options
function  bpdaily_customize_controls_footer() {
	global $options, $shortname, $shortprefix;
	?>
	<style type="text/css">
		.customize-control-title { line-height: 18px; padding: 2px 0; }
		.customize-control-description { font-size: 11px; color: #666; margin: 0 0 3px; display: block; }
		.customize-control input[type="text"], .customize-control textarea { width: 98%; line-height: 18px; margin: 0; }
	</style>
	<?php
}
add_action('customize_controls_print_footer_scripts', 'bpdaily_customize_controls_footer');



function bpdaily_option_in_customize( $option ){
	global $shortname, $shortprefix, $bp_existed;
	$ids = array(
		/*$shortname . $shortprefix  . "featuretype",
		$shortname . $shortprefix  . "video_code",
		$shortname . $shortprefix  . "video_title",
		$shortname . $shortprefix  . "video_description",
		$shortname . $shortprefix  . "slideshow_speed",
		$shortname . $shortprefix  . "slideshow_number",
		$shortname . $shortprefix  . "feature_cat",
		$shortname . $shortprefix  . "feature_image_size",
		$shortname . $shortprefix  . "tabone_title",
		$shortname . $shortprefix  . "tabtwo_title",
		$shortname . $shortprefix  . "tabthree_title",
		$shortname . $shortprefix  . "tabcat_one",
		$shortname . $shortprefix  . "tabcat_two",
		$shortname . $shortprefix  . "tabcat_three",
		$shortname . $shortprefix  . "featuretabs_image_size",
		$shortname . $shortprefix  . "latesttype",
		$shortname . $shortprefix  . "wall_number",
		$shortname . $shortprefix  . "featurecat_row_num",
		$shortname . $shortprefix  . "featurecat_one",
		$shortname . $shortprefix  . "featurecat_two",
		$shortname . $shortprefix  . "featurecat_three",
		$shortname . $shortprefix  . "featurecat_four",
		$shortname . $shortprefix  . "featurecat_five",
		$shortname . $shortprefix  . "featurecat_six",
		$shortname . $shortprefix  . "featurecat_seven",
		$shortname . $shortprefix  . "featurecat_eight",
		$shortname . $shortprefix  . "featurecat_nine",
		$shortname . $shortprefix  . "featurecat_image_size",
		$shortname . $shortprefix  . "featurecat_rows",
		$shortname . $shortprefix  . "featurecat_rows_num",
		$shortname . $shortprefix  . "signupfeat_on",
		$shortname . $shortprefix  . "signupfeat_text",
		$shortname . $shortprefix  . "signupfeat_buttontext",
		$shortname . $shortprefix  . "signupfeat_buttontextcustom",
		$shortname . $shortprefix  . "spotlight_category",
		$shortname . $shortprefix  . "spotlight_number",
		$shortname . $shortprefix  . "spotlight_image_size",
		$shortname . $shortprefix  . "header_advert",
		$shortname . $shortprefix  . "header_advert_title",
		$shortname . $shortprefix  . "header_advert_link",
		$shortname . $shortprefix  . "header_advert_code",
		$shortname . $shortprefix  . "wide_advert",
		$shortname . $shortprefix  . "wide_advert_title",
		$shortname . $shortprefix  . "wide_advert_link",
		$shortname . $shortprefix  . "sideleft_advert",
		$shortname . $shortprefix  . "sideleft_advert_title",
		$shortname . $shortprefix  . "sideleft_advert_link",
		$shortname . $shortprefix  . "sideleft_advert_code",
		$shortname . $shortprefix  . "sideright_advert",
		$shortname . $shortprefix  . "sideright_advert_title",
		$shortname . $shortprefix  . "sideright_advert_link",
		$shortname . $shortprefix  . "sideright_advert_code",
		$shortname . $shortprefix  . "header_image",
		$shortname . $shortprefix  . "header_logo",
		$shortname . $shortprefix  . "header_image_square",
		$shortname . $shortprefix  . "header_logo_square",*/
		$shortname . $shortprefix  . "body_font",
		$shortname . $shortprefix  . "header_font",
		$shortname . $shortprefix  . "h1_colour",
		$shortname . $shortprefix  . "h2_colour",
		$shortname . $shortprefix  . "h3_colour",
		$shortname . $shortprefix  . "h4_colour",
		$shortname . $shortprefix  . "h5_colour",
		$shortname . $shortprefix  . "h6_colour",
		$shortname . $shortprefix  . "header_background_colour",
		$shortname . $shortprefix  . "header_feature_border_colour",
		$shortname . $shortprefix  . "header_feature_colour",
		$shortname . $shortprefix  . "button_border",
		$shortname . $shortprefix  . "button_background_colour",
		$shortname . $shortprefix  . "button_colour",
		$shortname . $shortprefix  . "button_background_image",
		$shortname . $shortprefix  . "button_image_repeat",
		$shortname . $shortprefix  . "button_hover_border_colour",
		$shortname . $shortprefix  . "button_hover_background_colour",
		$shortname . $shortprefix  . "button_hover_colour",
		$shortname . $shortprefix  . "button_hover_background_image",
		$shortname . $shortprefix  . "button_hover_image_repeat",
		$shortname . $shortprefix  . "input_border_colour",
		$shortname . $shortprefix  . "input_background_colour",
		$shortname . $shortprefix  . "input_text_colour",
		$shortname . $shortprefix  . "label_colour",
		$shortname . $shortprefix  . "textarea_background_colour",
		$shortname . $shortprefix  . "textarea_border_colour",
		$shortname . $shortprefix  . "textarea_text_colour",
		$shortname . $shortprefix  . "whats_border_colour",
		$shortname . $shortprefix  . "link_colour",
		$shortname . $shortprefix  . "link_hover_colour",
		$shortname . $shortprefix  . "link_visited_colour",
		$shortname . $shortprefix  . "byline_colour",
		$shortname . $shortprefix  . "pre_colour",
		$shortname . $shortprefix  . "hr_colour",
		$shortname . $shortprefix  . "pre_background_colour",
		$shortname . $shortprefix  . "body_colour",
		$shortname . $shortprefix  . "body_background_colour",
		$shortname . $shortprefix  . "body_background_image",
		$shortname . $shortprefix  . "body_image_repeat",
		$shortname . $shortprefix  . "load_background_colour",
		$shortname . $shortprefix  . "load_border_colour",
		$shortname . $shortprefix  . "load_text_colour",
		$shortname . $shortprefix  . "child_background_colour",
		$shortname . $shortprefix  . "child_colour",
		$shortname . $shortprefix  . "child_border_colour",
		$shortname . $shortprefix  . "child_hover_background_colour",
		$shortname . $shortprefix  . "child_hover_text_colour",
		$shortname . $shortprefix  . "image_border_colour",
		$shortname . $shortprefix  . "information_colour",
		$shortname . $shortprefix  . "activity_comments_colour",
		$shortname . $shortprefix  . "activity_comments_background_colour",
		$shortname . $shortprefix  . "activity_comments_border_colour",
		$shortname . $shortprefix  . "activity_background_colour",
		$shortname . $shortprefix  . "activity_colour",
		$shortname . $shortprefix  . "activity_border_colour",
		$shortname . $shortprefix  . "activity_hover_background_colour",
		$shortname . $shortprefix  . "activity_hover_colour",
		$shortname . $shortprefix  . "activity_hover_border_colour",
		$shortname . $shortprefix  . "invite_background_colour",
		$shortname . $shortprefix  . "invite_border_colour",
		$shortname . $shortprefix  . "invite_text_colour",
		$shortname . $shortprefix  . "item_border_colour",
		$shortname . $shortprefix  . "author_box_background_colour",
		$shortname . $shortprefix  . "author_box_border_colour",
		$shortname . $shortprefix  . "widget_background_colour",
		$shortname . $shortprefix  . "widget_colour",
		$shortname . $shortprefix  . "widget_border_colour",
		$shortname . $shortprefix  . "caption_background_colour",
		$shortname . $shortprefix  . "caption_border_colour",
		$shortname . $shortprefix  . "spotlight_background_colour",
		$shortname . $shortprefix  . "spotlight_colour",
		$shortname . $shortprefix  . "spotlight_border_colour",
		$shortname . $shortprefix  . "widget_title_background_colour",
		$shortname . $shortprefix  . "widget_title_colour",
		$shortname . $shortprefix  . "wrapper_background_colour",
		$shortname . $shortprefix  . "wrapper_border_colour",
		$shortname . $shortprefix  . "pagination_border_colour",
		$shortname . $shortprefix  . "column_border_colour",
		$shortname . $shortprefix  . "container_background_colour",
		$shortname . $shortprefix  . "container_colour",
		$shortname . $shortprefix  . "dark_background_colour",
		$shortname . $shortprefix  . "dark_border_colour",
		$shortname . $shortprefix  . "dark_text_colour",
		$shortname . $shortprefix  . "light_background_colour",
		$shortname . $shortprefix  . "light_border_colour",
		$shortname . $shortprefix  . "light_text_colour",
		$shortname . $shortprefix  . "sidebar_item_background_colour",
		$shortname . $shortprefix  . "sidebar_item_colour",
		$shortname . $shortprefix  . "breadcrumb_background_colour",
		$shortname . $shortprefix  . "breadcrumb_border_colour",
		$shortname . $shortprefix  . "breadcrumb_colour",
		$shortname . $shortprefix  . "category_background_colour",
		$shortname . $shortprefix  . "category_border_colour",
		$shortname . $shortprefix  . "category_menu_border_colour",
		$shortname . $shortprefix  . "category_menu_background_colour",
		$shortname . $shortprefix  . "category_menu_colour",
		$shortname . $shortprefix  . "category_menu_selected_background_colour",
		$shortname . $shortprefix  . "category_menu_selected_colour",
		$shortname . $shortprefix  . "pagination_background_colour",
		$shortname . $shortprefix  . "pagination_border_colour",
		$shortname . $shortprefix  . "pagination_menu_border_colour",
		$shortname . $shortprefix  . "pagination_menu_background_colour",
		$shortname . $shortprefix  . "pagination_menu_colour",
		$shortname . $shortprefix  . "pagination_menu_selected_background_colour",
		$shortname . $shortprefix  . "pagination_menu_selected_colour",
		$shortname . $shortprefix  . "highlight_background_colour",
		$shortname . $shortprefix  . "highlight_border_colour",
		$shortname . $shortprefix  . "highlight_colour",
		$shortname . $shortprefix  . "tabs_background_colour",
		$shortname . $shortprefix  . "tabs_text_colour",
		$shortname . $shortprefix  . "tabs_selected_background_colour",
		$shortname . $shortprefix  . "tabs_selected_colour",
		$shortname . $shortprefix  . "tabs_sub_background_colour",
		$shortname . $shortprefix  . "tabs_sub_border_colour",
		$shortname . $shortprefix  . "tabs_sub_colour",
		$shortname . $shortprefix  . "tabs_unread_colour",
		$shortname . $shortprefix  . "footer_background_colour",
		$shortname . $shortprefix  . "footer_colour",
		$shortname . $shortprefix  . "footer_link_colour",
		$shortname . $shortprefix  . "table_border_colour",
		$shortname . $shortprefix  . "alt_background_colour",
		$shortname . $shortprefix  . "alt_row_colour",
		$shortname . $shortprefix  . "sticky_background_colour",
		$shortname . $shortprefix  . "sticky_colour",
		$shortname . $shortprefix  . "unread_background_colour",
		$shortname . $shortprefix  . "unread_border_colour",
		$shortname . $shortprefix  . "unread_colour",
		$shortname . $shortprefix  . "pending_border_colour",
		$shortname . $shortprefix  . "pending_colour",
		$shortname . $shortprefix  . "pending_hover_border_colour",
		$shortname . $shortprefix  . "pending_hover_colour",
		$shortname . $shortprefix  . "messages_background_colour",
		$shortname . $shortprefix  . "messages_border_colour",
		$shortname . $shortprefix  . "messages_colour",
		$shortname . $shortprefix  . "updated_background_colour",
		$shortname . $shortprefix  . "updated_border_colour",
		$shortname . $shortprefix  . "updated_text_colour",
		$shortname . $shortprefix  . "message_options_background_colour",
		$shortname . $shortprefix  . "nessage_options_colour",
		$shortname . $shortprefix  . "error_background_colour",
		$shortname . $shortprefix  . "error_border_colour",
		$shortname . $shortprefix  . "error_colour",
		$shortname . $shortprefix  . "messages_alt_background_colour",
		$shortname . $shortprefix  . "messages_alt_colour",
		$shortname . $shortprefix  . "topic_alt_background_colour",
		$shortname . $shortprefix  . "topic_alt_colour",
		$shortname . $shortprefix  . "unread_background_colour",
		$shortname . $shortprefix  . "unread_border_colour",
		$shortname . $shortprefix  . "unread_colour",
		$shortname . $shortprefix  . "slideshow_background_colour",
		$shortname . $shortprefix  . "slideshow_content_background_colour",
		$shortname . $shortprefix  . "slideshow_image_background_colour",
		$shortname . $shortprefix  . "slideshow_colour",
		$shortname . $shortprefix  . "tabs_first_background_colour",
		$shortname . $shortprefix  . "tabs_first_colour",
		$shortname . $shortprefix  . "tabs_second_background_colour",
		$shortname . $shortprefix  . "tabs_second_colour",
		$shortname . $shortprefix  . "tabs_third_background_colour",
		$shortname . $shortprefix  . "tabs_third_colour",
		$shortname . $shortprefix  . "tabs_nav_background_colour",
		$shortname . $shortprefix  . "tabs_nav_border_colour",
		$shortname . $shortprefix  . "tabs_nav_link_colour",
		$shortname . $shortprefix  . "tabs_nav_link_background_colour",
	);
	$get_current_scheme = get_option('dev_buddydaily_custom_style');
	if(($get_current_scheme != '') && ($get_current_scheme != 'default.css')) {
		return false;
	}
	if ( in_array( $option['id'], $ids ) )
		return true;
	return false;
}

?>